function fluofitsurf(beta, opt, desc)
%FLUOFITSURF Plot 2d surface of fitted fluorescence spectra.
%   FLUOFITSURF(BETA, OPT, DESC) plots the 2d surface of fitted
%   fluorescence spectra as a mesh and an image.
%
%   EXAMPLE:
%      fluofitsurf(beta, opt, fluofitdesc(data, em, ex, opt));
%
%   AUTHOR:
%      Wouter Caarls, MPIbpc <wouter@caarls.org>

    colors = 'rgb';
    markers = 'osd';
    
    desc.exs = length(desc.ex);
    desc.ems = length(desc.em);

    hs = opt.bands*3;
    or = (length(beta)-hs)/desc.reps;
    r = 1;

    nem = min(desc.em):200:max(desc.em);
    nex = min(desc.ex):200:max(desc.ex);
    nem2 = min(desc.em):50:max(desc.em);
    nex2 = min(desc.ex):50:max(desc.ex);
    
    [dx, dy] = meshgrid(nem, nex);
    [dx2, dy2] = meshgrid(nem2, nex2);
    [mx, my] = meshgrid(10^7./nem, 10^7./nex);
    [mx2, my2] = meshgrid(10^7./nem2, 10^7./nex2);
    mz = zeros(size(mx));
    mz2 = zeros(size(mx2));

    for b = 1:opt.bands
        y = beta(hs+(r-1)*or+(b-1)*desc.exs+[1:desc.exs]);
        if opt.wavenumber
            beta0 = [1.5 3000 10^7/420 max(y)];
        else
            beta0 = [1.5 60 420 max(y)];
        end

        p = sum(desc.data(:,:,r), 1)>0;
        ebeta(((b-1)*4+1):(b*4)) = nlinfit(desc.ex(p), y(p), @alognmdl, beta0, statset('DerivStep', 0.01));
    end        
        
    for b = 1:opt.bands
        mz1 = alogn(beta((b-1)*3+1), beta((b-1)*3+2), beta((b-1)*3+3), ...
                    alogn(ebeta((b-1)*4+1), ebeta((b-1)*4+2), ebeta((b-1)*4+3), ebeta((b-1)*4+4), dy), dx);
        mz = mz + mz1;
        mz1 = alogn(beta((b-1)*3+1), beta((b-1)*3+2), beta((b-1)*3+3), ...
                    alogn(ebeta((b-1)*4+1), ebeta((b-1)*4+2), ebeta((b-1)*4+3), ebeta((b-1)*4+4), dy2), dx2);
        mz2 = mz2 + mz1;
        %surf(mx, my, mz1, max(max(max(desc.data))).*(b-1).*ones(size(mz1))./(opt.bands-1));
        %hold on
        
        switch b
            case 1
                d = 0.1;
            case 3
                d = 0.2;
            otherwise
                d = 0;
        end
        
        plot3(mx2(:, end)+d, my2(:, 1), alogn(ebeta((b-1)*4+1), ebeta((b-1)*4+2), ebeta((b-1)*4+3), ebeta((b-1)*4+4), dy2(:,1)), [colors(b) '-'], 'linewidth', 2);
        hold on
        plot3(mx2(1:10:end, end)+d, my2(1:10:end, 1), alogn(ebeta((b-1)*4+1), ebeta((b-1)*4+2), ebeta((b-1)*4+3), ebeta((b-1)*4+4), dy2(1:10:end,1)), [colors(b) markers(b)], 'markersize', 5);
        plot3(mx2(1, :), my2(end, :)+d, alogn(beta((b-1)*3+1), beta((b-1)*3+2), beta((b-1)*3+3), ebeta((b-1)*4+4), dx2(1,:)), [colors(b) '-'], 'linewidth', 2);
        plot3(mx2(1, 1:10:end), my2(end, 1:10:end)+d, alogn(beta((b-1)*3+1), beta((b-1)*3+2), beta((b-1)*3+3), ebeta((b-1)*4+4), dx2(1,1:10:end)), [colors(b) markers(b)], 'markersize', 5);
    end
    
    dist = sqrt(((mx-min(min(mx)))/(max(max(mx))-min(min(mx)))).^2 + ...
                ((my-min(min(my)))/(max(max(my))-min(min(my)))).^2);
    
    mesh(mx, my, mz, 1-dist/sqrt(2));%, 0.5*ones(size(mz)));
    %surf(mx, my, zeros(size(mz)), (mz-min(min(mz)))/(max(max(mz))-min(min(mz))));
    %surf(mx, my, zeros(size(mz)), 0.5+((mz-min(min(mz)))/(max(max(mz))-min(min(mz))))/2);
    surf(mx2, my2, zeros(size(mz2)), 1-(mz2-min(min(mz2)))/(max(max(mz2))-min(min(mz2))));
    colormap gray

    %[ox, oy] = meshgrid(10^7./desc.em, 10^7./desc.ex);
    %surf(ox, oy, desc.data(:,:,r)');
    set(gca, 'ytick', 350:25:450);
    axis tight

    h = xlabel('Emission wavelength (nm)');
    set(h, 'rotation', 9);
    
    h = ylabel('Excitation wavelength (nm)');
    set(h, 'rotation', -27);

    zlabel('Fluorescence intensity (a.u.)');
    
    shading flat
    hidden off
    hold off
    grid on
    view(151,22);

    