function fluofitwrite(datacal, em, ex, beta, base, opt)
%FLUOFITWRITE Write fitting parameters to file.
%   FLUOFITWRITE(DATA, EM, EX, BETA, BASE, OPT) writes the fitting
%   parameters of the fitted fluorescence spectra in DATA, EM, EX, BETA to
%   a text file BASE.txt. Additionally, it saves the plots as .png.
%   OPT is the options structure returned by FLUOFIT.
%
%   EXAMPLE:
%      fluofitwrite(data, em, ex, beta, 'myfit', opt);
%
%   AUTHOR:
%      Wouter Caarls, MPIbpc <wouter@caarls.org>

    if nargin < 6
        opt = fluofitopt();
    end

    fid = fopen([base '.txt'], 'wt');
    fprintf(fid, '%s\n\n', val2str(opt));
    fclose(fid);

    save(base, 'datacal', 'em', 'ex', 'beta', 'opt');
    
    if iscell(beta)
        fid = fopen([base '.txt'], 'at');
        for i = 1:length(beta)
            figure;
            set(gcf, 'visible', 'off', 'Position', [0 0 1200 800]);
            fluofitplot(beta{i}, opt, fluofitdesc(datacal(:,:,i), em, ex, opt), fid);
            exportfig(gcf, [base '_' num2str(i) '.png'], 'format', 'png', 'color', 'cmyk', 'width', 7.25, 'resolution', 300);
            close(gcf);
        end
        fclose(fid);
    else
        figure;
        set(gcf, 'visible', 'off', 'Position', [0 0 1600 600]);
        fid = fopen([base '.txt'], 'at');
        fluofitplot(beta, opt, fluofitdesc(datacal, em, ex, opt), fid);
        fclose(fid);
        exportfig(gcf, [base '.png'], 'format', 'png', 'color', 'cmyk', 'width', 10.8, 'resolution', 300);
        close(gcf);
    end
end




